@@ -12,3 +12,7 @@ def set_pytorch_random_state(seed=42):
     torch.manual_seed(seed)
     torch.cuda.manual_seed(seed)
     torch.backends.cudnn.deterministic = True
+
+
+def pytorch_state(seed, device):
+    return torch.Generator(device).manual_seed(seed)
